@@ -4,9 +4,9 @@ use warnings;
 package Util::H2O::More;
 use parent q/Exporter/;
 
-our $VERSION = q{0.2.1};
+our $VERSION = q{0.2.3};
 
-our @EXPORT_OK = (qw/baptise opt2h2o h2o o2h d2o o2d/);
+our @EXPORT_OK = (qw/baptise opt2h2o h2o o2h d2o o2d o2h2o ini2o o2ini/);
 
 use Util::H2O ();
 
@@ -59,13 +59,35 @@ sub baptise ($$@) {
 # preconditioner for use with Getopt::Long flags; returns just the flag name given
 # a list of option descriptors, e.g., qw/option1=s option2=i option3/;
 
-# flags to keys
+# Getopts to keys
 sub opt2h2o(@) {
     my @getopt_def = @_;
     my @flags_only = map { m/([^=|\s]+)/g; $1 } @getopt_def;
     return @flags_only;
 }
 
+# general form of method used to give accessors to Config::Tiny in Util::H2O's
+# POD documentation
+sub o2h2o ($) {
+   my $ref = shift;
+   return h2o -recurse, {%{ $ref }};
+}
+
+# more specific helper app that uses Config::Tiny->read and o2h2o to get a config
+# object back from an .ini; requries Config::Tiny
+sub ini2o ($) {
+   my $filename = shift;
+   require Config::Tiny;
+   return o2h2o( Config::Tiny->read($filename) );
+}
+
+# write out the INI file
+sub o2ini ($$) {
+  my ($config, $filename) = @_;
+  require Config::Tiny;
+  return Config::Tiny->new(Util::H2O::o2h $config)->write($filename);
+}
+
 # return a dereferences hash (non-recursive); reverse of `h2o'
 sub o2h($) {
     $Util::H2O::_PACKAGE_REGEX = qr/::_[0-9A-Fa-f]+\z/; # makes internal package name more generic for baptise created references
@@ -320,10 +342,9 @@ C<baptise> and C<bastise -recurse>.
 
 =head2 C<opt2h2o LIST>
 
-Handy function for working with C<Getopt::Long>, which takes
-a list of options meant for C<Getopt::Long>; and extracts the
-flag names so that they may be used to create default accessors
-without having more than one list. E.g.,
+Handy function for working with C<Getopt::Long>, which takes a list of options
+meant for C<Getopt::Long>; and extracts the flag names so that they may be
+used to create default accessors without having more than one list. E.g.,
 
     use Getopt::Long qw//;
     my @opts = (qw/option1=s options2=s@ option3 option4=i o5|option5=s/);
@@ -335,9 +356,9 @@ without having more than one list. E.g.,
       do_the_thing();
     }
 
-Note: default values for options may still be placed inside
-of the anonymous hash being I<objectified> via C<h2o>. This
-will work perfectly well with C<baptise> and friends.
+Note: default values for options may still be placed inside of the anonymous
+hash being I<objectified> via C<h2o>. This will work perfectly well with
+C<baptise> and friends.
 
     use Getopt::Long qw//;
     my @opts = (qw/option1=s options2=s@ option3 option4=i o5|option5=s/);
@@ -348,6 +369,49 @@ will work perfectly well with C<baptise> and friends.
     # now $o can be used to query all possible options, even if they were
     # never passed at the commandline 
 
+=head2 C<ini2o FILENAME>
+
+Takes the name of a file, uses L<Config::Tiny> to open it, then gives it
+accessors using internally, C<o2h2o>, described below.
+
+Given some configuration file using INI:
+
+  [section1]
+  var1=foo
+  var2=bar
+  
+  [section2]
+  var3=herp
+  var4=derp
+
+We can parse it with L<Config::Tiny> and objectify it with C<h2o>:
+
+  use Util::H2O::More qw/ini2o/;
+  my $config = ini2o qq{/path/to/my/config.ini}
+  # ... $config now has accessors based Config::Tiny's read of config.ini
+
+=head2 C<o2ini REF, FILENAME>
+
+Takes and object created via C<ini2o> and writes it back out to C<FILENAME>
+in the proper I<INI> format, using L<Config::Tiny>.
+
+Given the example in C<ini2o>, we can go a step further and writ eout a new
+configuration file after reading it and modifying a value.
+
+  use Util::H2O::More qw/ini2o o2ini/;
+
+  my $config = ini2o q{/path/to/my/config.ini}
+
+  # update $config, write it out as a different file
+  $config->section1->var1("some new value");
+  o2ini $config, q{/path/to/my/other-config.ini};
+
+=head2 C<o2h2o REF>
+
+Primarily inspired by L<Util::H2O>'s example for adding accessors to an
+reference that has already been blessed by another package. The motivating
+example is one that shows how to add accessors to a L<Config::Tiny> object.
+
 =head2 C<o2h REF>
 
 Uses C<Util::H2O::o2h>, so behaves identical to it.  A new hash reference
